==> aom-docs-3.1.1-1-aarch64.pkg.tar.xz: usr/share/doc/aom/structMB__MODE__INFO.js <==
var structMB__MODE__INFO =
[
    [ "bsize", "structMB__MODE__INFO.html#af56bd81bd112b27eaeb683a7e7a6a501", null ],
    [ "partition", "structMB__MODE__INFO.html#af2cde63779206854f309b9096495b059", null ],
    [ "mode", "structMB__MODE__INFO.html#a3b7eb48f50423ce4909ee117ba1ea01f", null ],
    [ "uv_mode", "structMB__MODE__INFO.html#a769818d35e7348a4317659398075e49a", null ],
    [ "current_qindex", "structMB__MODE__INFO.html#aa4fb72f51372fdbc9508f960b4027fc5", null ],
    [ "mv", "structMB__MODE__INFO.html#a1570ec23444b02ce6bce496b0af637a2", null ],
    [ "ref_frame", "structMB__MODE__INFO.html#a91ba670a94fa1cbc455c41501ef960a4", null ],
    [ "interp_filters", "structMB__MODE__INFO.html#a05cda5be151da599d4257c4fc9db9a46", null ],
    [ "motion_mode", "structMB__MODE__INFO.html#ac2172afa622ea4f71ebb1762895de72a", null ],
    [ "num_proj_ref", "structMB__MODE__INFO.html#ac9e8aefd4ada6ca113092377fbadfa33", null ],
    [ "overlappable_neighbors", "structMB__MODE__INFO.html#a89abe2416d8601545822281a59f07105", null ],
    [ "wm_params", "structMB__MODE__INFO.html#ac03e5caa7a96b9d5651654725d0806c4", null ],
    [ "interintra_mode", "structMB__MODE__INFO.html#af19e4bb9df7c1699716a8075fc2fd9ce", null ],
    [ "interintra_wedge_index", "structMB__MODE__INFO.html#a13f1a883e73c4b721c2212d0416b3967", null ],
    [ "interinter_comp", "structMB__MODE__INFO.html#a507bd43a10bd640d1e956befe6902f1c", null ],
    [ "angle_delta", "structMB__MODE__INFO.html#aa7e2a8b28abe490b2ea1a35009be7b9b", null ],
    [ "filter_intra_mode_info", "structMB__MODE__INFO.html#ab0502d3124c57d58d1b726fe3c6e0078", null ],
    [ "cfl_alpha_signs", "structMB__MODE__INFO.html#adcf9eae6769f40de4416b57fb4b565c1", null ],
    [ "cfl_alpha_idx", "structMB__MODE__INFO.html#a80b6f65a3361030cde834acad9b38f21", null ],
    [ "palette_mode_info", "structMB__MODE__INFO.html#a78e61449b1aaf129f0706e876eaa252f", null ],
    [ "skip_txfm", "structMB__MODE__INFO.html#aad38178f7b432ef5902f7f47955c4555", null ],
    [ "tx_size", "structMB__MODE__INFO.html#afd40fafa9224edce279c1c6a52b7fc95", null ],
    [ "inter_tx_size", "structMB__MODE__INFO.html#a98f3fad5a4f79313d5a7f5b1935cdca5", null ],
    [ "delta_lf_from_base", "structMB__MODE__INFO.html#a02b7e164e73fcad61b9167033cecd63d", null ],
    [ "delta_lf", "structMB__MODE__INFO.html#a3643a8af086d4b016131a07878ffd88e", null ],
    [ "segment_id", "structMB__MODE__INFO.html#a79704bc4fbe9b3e431e874f7353d1d1e", null ],
    [ "seg_id_predicted", "structMB__MODE__INFO.html#acd3079b438148541ea2bd7e7c094c52f", null ],
    [ "ref_mv_idx", "structMB__MODE__INFO.html#a826e27476434a97d326cda91263c69ea", null ],
    [ "skip_mode", "structMB__MODE__INFO.html#aeb877fdf434a69dda252e4c03ddfba36", null ],
    [ "use_intrabc", "structMB__MODE__INFO.html#afe580c6b4c9288247b4f52afb0f3764f", null ],
    [ "comp_group_idx", "structMB__MODE__INFO.html#ae6943bd68aa3915764d01c862d4981f4", null ],
    [ "compound_idx", "structMB__MODE__INFO.html#a8552e37deea204df2caff7aa688f8ccf", null ],
    [ "use_wedge_interintra", "structMB__MODE__INFO.html#a6d5eaf4362e5063f595c98f6fcb01460", null ],
    [ "cdef_strength", "structMB__MODE__INFO.html#a9fabda2de19410e2e24c4369ad7a8b24", null ]
];

==> aom-docs-3.4.0-1-aarch64.pkg.tar.xz: usr/share/doc/aom/structMB__MODE__INFO.js <==
var structMB__MODE__INFO =
[
    [ "bsize", "structMB__MODE__INFO.html#af56bd81bd112b27eaeb683a7e7a6a501", null ],
    [ "partition", "structMB__MODE__INFO.html#af2cde63779206854f309b9096495b059", null ],
    [ "mode", "structMB__MODE__INFO.html#a3b7eb48f50423ce4909ee117ba1ea01f", null ],
    [ "uv_mode", "structMB__MODE__INFO.html#a769818d35e7348a4317659398075e49a", null ],
    [ "current_qindex", "structMB__MODE__INFO.html#aa4fb72f51372fdbc9508f960b4027fc5", null ],
    [ "mv", "structMB__MODE__INFO.html#a1570ec23444b02ce6bce496b0af637a2", null ],
    [ "ref_frame", "structMB__MODE__INFO.html#a91ba670a94fa1cbc455c41501ef960a4", null ],
    [ "interp_filters", "structMB__MODE__INFO.html#a05cda5be151da599d4257c4fc9db9a46", null ],
    [ "motion_mode", "structMB__MODE__INFO.html#ac2172afa622ea4f71ebb1762895de72a", null ],
    [ "num_proj_ref", "structMB__MODE__INFO.html#ac9e8aefd4ada6ca113092377fbadfa33", null ],
    [ "overlappable_neighbors", "structMB__MODE__INFO.html#a89abe2416d8601545822281a59f07105", null ],
    [ "wm_params", "structMB__MODE__INFO.html#ac03e5caa7a96b9d5651654725d0806c4", null ],
    [ "interintra_mode", "structMB__MODE__INFO.html#af19e4bb9df7c1699716a8075fc2fd9ce", null ],
    [ "interintra_wedge_index", "structMB__MODE__INFO.html#a13f1a883e73c4b721c2212d0416b3967", null ],
    [ "interinter_comp", "structMB__MODE__INFO.html#a507bd43a10bd640d1e956befe6902f1c", null ],
    [ "angle_delta", "structMB__MODE__INFO.html#aa7e2a8b28abe490b2ea1a35009be7b9b", null ],
    [ "filter_intra_mode_info", "structMB__MODE__INFO.html#ab0502d3124c57d58d1b726fe3c6e0078", null ],
    [ "cfl_alpha_signs", "structMB__MODE__INFO.html#adcf9eae6769f40de4416b57fb4b565c1", null ],
    [ "cfl_alpha_idx", "structMB__MODE__INFO.html#a80b6f65a3361030cde834acad9b38f21", null ],
    [ "palette_mode_info", "structMB__MODE__INFO.html#a78e61449b1aaf129f0706e876eaa252f", null ],
    [ "skip_txfm", "structMB__MODE__INFO.html#aad38178f7b432ef5902f7f47955c4555", null ],
    [ "tx_size", "structMB__MODE__INFO.html#afd40fafa9224edce279c1c6a52b7fc95", null ],
    [ "inter_tx_size", "structMB__MODE__INFO.html#a98f3fad5a4f79313d5a7f5b1935cdca5", null ],
    [ "delta_lf_from_base", "structMB__MODE__INFO.html#a02b7e164e73fcad61b9167033cecd63d", null ],
    [ "delta_lf", "structMB__MODE__INFO.html#a3643a8af086d4b016131a07878ffd88e", null ],
    [ "segment_id", "structMB__MODE__INFO.html#a79704bc4fbe9b3e431e874f7353d1d1e", null ],
    [ "seg_id_predicted", "structMB__MODE__INFO.html#acd3079b438148541ea2bd7e7c094c52f", null ],
    [ "ref_mv_idx", "structMB__MODE__INFO.html#a826e27476434a97d326cda91263c69ea", null ],
    [ "skip_mode", "structMB__MODE__INFO.html#aeb877fdf434a69dda252e4c03ddfba36", null ],
    [ "use_intrabc", "structMB__MODE__INFO.html#afe580c6b4c9288247b4f52afb0f3764f", null ],
    [ "comp_group_idx", "structMB__MODE__INFO.html#ae6943bd68aa3915764d01c862d4981f4", null ],
    [ "compound_idx", "structMB__MODE__INFO.html#a8552e37deea204df2caff7aa688f8ccf", null ],
    [ "use_wedge_interintra", "structMB__MODE__INFO.html#a6d5eaf4362e5063f595c98f6fcb01460", null ],
    [ "cdef_strength", "structMB__MODE__INFO.html#a9fabda2de19410e2e24c4369ad7a8b24", null ],
    [ "skip_cdef_curr_sb", "structMB__MODE__INFO.html#a08d18c7dae0e73191733c8e62722b3fc", null ]
];
